unit Info;

{ Demostration of palettes and animation in a Delphi component.
  Copyright  1997 Tempest Software, Inc.

  Present information about the video adapter.

  If you do not have "Secrets of Delphi 2", you can edit this file
  to remove the reference to the S_Rtti and S_Win units. You need
  to change the call to EnumName to GetEnumName, suitably modifying
  the arguments and the return type. (D1 and D2 return different types
  from GetEnumName. That's why I wrote EnumName, as a portable
  version of the function.) Change the call to SetFormParent to
  call SetWindowWord (Delphi 1) or SetWindowLong (Delphi 2), to
  set Gww_HwndParent (D1) or Gwl_HwndParent (D2).
}

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Buttons, ExtCtrls;

type
  TInfoForm = class(TForm)
    Memo: TMemo;
    Button1: TButton;
    procedure FormCreate(Sender: TObject);
  private
    procedure FmtInfo(const Fmt: string; Args: array of const);
  end;

var
  InfoForm: TInfoForm;

implementation

uses TypInfo, S_Rtti, S_Win;

{$R *.DFM}

{ Add formatted information to the dialog. }
procedure TInfoForm.FmtInfo(const Fmt: string; Args: array of const);
begin
  Memo.Lines.Add(Format(Fmt, Args));
end;

type
  TRasterCap = (BitBlt, Banding, Scaling, Bitmap64, GDI20_Output, DGI20_State,
                SaveBitmap, DI_Bitmap, Palette, DIBToDev, BitFont,
                StretchBlt, FloodFill, StretchDIB, OP_DX_Output, DevBits);
  TRasterCaps = set of TRasterCap;

procedure TInfoForm.FormCreate(Sender: TObject);
var
  DC: HDC;
  RC: TRasterCaps;
  R: TRasterCap;      { loop index }
begin
  { Make the dialog a formal child of the  main form. This prevents the
    use from accidentally bringing the main form on top of the dialog
    in Windows 95 or NT 4.0. }
  SetFormParent(Self, Application.MainForm.Handle);

  DC := Canvas.Handle; { for brevity in the GetDeviceCaps calls, below }
  SmallInt(RC) := GetDeviceCaps(DC, RasterCaps);

  Memo.Clear;
  Memo.Lines.Add('Display Information');
  FmtInfo('  Size: %d x %d', [GetDeviceCaps(DC, HorzRes), GetDeviceCaps(DC, VertRes)]);
  FmtInfo('  Bits/Pixel: %d', [GetDeviceCaps(DC, BitsPixel) * GetDeviceCaps(Dc, Planes)]);
  FmtInfo('  Pixels/Inch: %d x %d', [GetDeviceCaps(DC, LogPixelsX), GetDeviceCaps(DC, LogPixelsY)]);

  if Palette in RC then
  begin
    FmtInfo('  ColorRes: %d', [GetDeviceCaps(DC, ColorRes)]);
    FmtInfo('  SizePalette: %d', [GetDeviceCaps(DC, SizePalette)]);
    FmtInfo('  NumReserved: %d', [GetDeviceCaps(DC, NumReserved)]);
  end;

  Memo.Lines.Add('  Raster Caps:');
  for R := Low(TRasterCap) to High(TRasterCap) do
    if R in RC then
      Memo.Lines.Add('    ' + EnumName(Ord(R), TypeInfo(TRasterCap)));
end;

end.
 
