unit Palform;

{ Demostration of palettes and animation in a Delphi component.
  Copyright  1997 Tempest Software, Inc.

  This program demonstrate some simple uses for a display palettet
  in Windows, including palette animation. Palette animation works
  only with video adapters that use a system palette, so if the display
  does not use a palette, the animation start button is disabled.

  Most of the interesting stuff is in the PalDemo.pas file, which
  implements the TPaletteDemo component. This is the main form,
  which creates the TPaletteDemo component and animates it.

  The info button pops up a dialog that displays some information
  about the video driver.
}

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls, Spin, PalDemo, Buttons;

type
  TDemoForm = class(TForm)
    Panel1: TPanel;
    StartButton: TButton;
    StopButton: TButton;
    PaletteDemo: TPaletteDemo;
    Timer: TTimer;
    PixelLabel: TLabel;
    InfoButton: TBitBtn;
    procedure StartButtonClick(Sender: TObject);
    procedure StopButtonClick(Sender: TObject);
    procedure TimerTimer(Sender: TObject);
    procedure PaletteDemoMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure Panel1MouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure FormCreate(Sender: TObject);
    procedure InfoButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  DemoForm: TDemoForm;

implementation

{$R *.DFM}

uses Info;

procedure TDemoForm.StartButtonClick(Sender: TObject);
begin
  StartButton.Enabled := False;
  StopButton.Enabled := True;
  Timer.Enabled := True;
end;

procedure TDemoForm.StopButtonClick(Sender: TObject);
begin
  Timer.Enabled := False;
  StopButton.Enabled := False;
  StartButton.Enabled := True;
end;

procedure TDemoForm.TimerTimer(Sender: TObject);
var
  Pt: TPoint;
begin
  PaletteDemo.Animate;
  { If the mouse is over the palette control, update the pixel color. }
  GetCursorPos(Pt);
  Pt := PaletteDemo.ScreenToClient(Pt);
  if PtInRect(PaletteDemo.ClientRect, Pt) then
    PaletteDemoMouseMove(nil, [], Pt.X, Pt.Y);
end;

procedure TDemoForm.PaletteDemoMouseMove(Sender: TObject;
  Shift: TShiftState; X, Y: Integer);
var
  Color: TColor;
begin
  Color := PaletteDemo.Canvas.Pixels[X, Y];
  PixelLabel.Caption := Format('(%d, %d) = $%6.6X', [X, Y, Color]);
end;

procedure TDemoForm.Panel1MouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);
begin
  PixelLabel.Caption := '';
end;

procedure TDemoForm.FormCreate(Sender: TObject);
begin
  { Check the display. If it does not use a palette, then do not
    try to animate the palette. }
  if (Rc_Palette and GetDeviceCaps(Canvas.Handle, RasterCaps)) = 0 then
    StartButton.Enabled := False;
end;

procedure TDemoForm.InfoButtonClick(Sender: TObject);
var
  InfoForm: TInfoForm;
begin
  InfoForm := TInfoForm.Create(Application);
  try
    InfoForm.ShowModal;
  finally
    InfoForm.Free;
  end;
end;

end.
